require 'spec_helper.rb'

describe Endicia::Label do
  subject(:label) { described_class.new }

  describe "#request_label", vcr: { record: :new_episodes } do
    let(:values) {
      {
        ToName: Faker::Name.name,
        ToCompany: Faker::Company.name,
        ToPostalCode: "90210",
        ToAddress1: Faker::Address.street_address,
        ToAddress2: Faker::Address.secondary_address,
        ToCity: Faker::Address.city,
        ToState: "CA",
        PartnerTransactionID: 12345,
        PartnerCustomerID: 45678,
        MailClass: "Priority",
        MailpieceShape: "Parcel",
        ToZIP4: '1234',
        WeightOz: "32", # 2 pounds
        DeliveryTimeDays: 'TRUE',
        EstimatedDeliveryDate: 'TRUE',
        ResponseOptions: {
          PostagePrice: 'TRUE',
        },
        MailpieceDimensions: {
          Length: "12",
          Width:  "16",
          Height: "18",
        },
        FromCompany: Faker::Company.name,
        ReturnAddress1: Faker::Address.street_address,
        ReturnAddress2: Faker::Address.secondary_address,
        FromCity: Faker::Address.city,
        FromState: "DC",
        FromPostalCode: "20005",
        FromZIP4: "1234",
        FromPhone: "2025551212",
      }
    }

    it "makes a request and properly parses the result" do
      response = label.request_label({ nodes: values, attrs: {} }, { log_requests: true, log_responses: true })
      expect(response.status).to eq("0")
      expect(response.tracking_number).to_not be_blank
      expect(response.final_postage).to match(/^\d+\.\d+/)
      expect(response.transaction_date_time).to match(/^\d{14}$/)
      expect(response.transaction_id).to_not be_blank
      expect(response.postmark_date).to match(/^\d{8}$/)
      expect(response.postage_balance).to match(/^\d+\.\d+/)
      expect(response.pic).to_not be_blank
      expect(response.error_message).to be_blank
      expect(response.reference_id).to be_blank
      expect(response.reference_id2).to be_blank
      expect(response.reference_id3).to be_blank
      expect(response.reference_id4).to be_blank
      expect(response.requester_id).to_not be_blank
      expect(response.cost_center).to_not be_blank
      expect(response.request_url).to_not be_blank
      expect(response.request_body).to_not be_blank
      expect(response.postage_price['Postage']['Zone']).to_not be_blank
      expect(response.postage_price['EstimatedDeliveryDate']).to_not be_blank
      expect(response.postage_price['DeliveryTimeDays']).to_not be_blank
    end

    it "handles a nonsense request" do
      response = label.request_label({ nodes: {}, attrs: {} }, { log_requests: true, log_responses: true })
      expect(response.status).to_not eq("0")
    end
  end
end
