require 'logger'

require 'webmock'
require 'vcr'
require 'faker'

require 'endicia_ruby'

require 'dotenv'
Dotenv.load

WebMock.disable_net_connect!
VCR.configure do |c|
  c.cassette_library_dir     = 'spec/vcr-cassettes'
  c.hook_into                :webmock
  c.default_cassette_options = { :record => :new_episodes }
  c.allow_http_connections_when_no_cassette = false
  c.ignore_localhost = true
  c.ignore_hosts 'localhost', 'amazonaws.com', 's3.amazonaws.com', 'stitchfix-dev.s3.amazonaws.com'
  c.configure_rspec_metadata!
  c.preserve_exact_body_bytes do |http_message|
    http_message.body.encoding.name == 'ASCII-8BIT' ||
    !http_message.body.valid_encoding?
  end
  c.filter_sensitive_data('PassPhrase') { ENV['ENDICIA_PASSPHRASE'] }
  c.filter_sensitive_data('AccountID') { ENV['ENDICIA_ACCOUNT_ID'] }
end

RSpec.configure do |config|
  config.order = "random"
  config.expect_with :rspec do |c|
    c.syntax = :expect
  end
end

module Kernel
  alias :original_warn :warn
  def warn(*args)
    if args.length == 1 && args[0] == 'Digest::Digest is deprecated; use Digest'
    else
      original_warn(*args)
    end
  end
end

module Rails
  def self.root
    File.expand_path(File.join(File.dirname(__FILE__),'..'))
  end

  def self.env
    'test'
  end

  def self.logger
    @logger ||= Logger.new(STDERR).tap { |_|
      _.level = Logger::ERROR 
    }
  end
end
